=================================
Obtaining a Code Signing identity
=================================

If you are intending to distribute an application, it is advisable (and, on
some platforms, necessary) to code sign your application. This is a
cryptographic process that identifies you as a developer, and identifies your
application as something that has been distributed by you.

The process of obtaining a code signing identity is slightly different on
every platform. The following are guides for every platform that Briefcase
supports:

.. toctree::
   :maxdepth: 1

   android
   macOS
   windows
